@@ -32,15 +32,10 @@ class ClassLoader(object):
         if ':' in class_spec:
             egg_name, module_path = class_spec.split(':')
 
-        module = importlib.import_module(module_path)
-
-        if module:
-            return module
-
-        if egg_name:
+        if not importlib.import_module(module_path) and egg_name:
             self._install_egg(egg_name)
 
-        return self.get_module(module)
+        return self.get_module(module_path)
 
     def get_class(self, class_module_path):
         """
@@ -88,4 +83,8 @@ class ClassLoader(object):
 
 def _get_classes_from_module(module):
     member_dict = dict(inspect.getmembers(module))
-    return [v for v in member_dict.values() if inspect.isclass(v)]
+
+    def is_class_from_module(cls):
+        return inspect.isclass(cls) and inspect.getmodule(cls) == module
+
+    return [v for v in member_dict.values() if is_class_from_module(v)]
